from os import path

import grapheme

EMOJI_FILE = path.join(path.dirname(__file__), 'emoji-test.txt')

def init_emoji_conversion(emoji_file=EMOJI_FILE):
    def generate_pairs(lines):
        for line in lines:
            line = line.strip()
            if line.startswith('#') or len(line) == 0:
                continue

            # lines are broken up like:
            #     CodePoints ; Status # Emoji EmojiName
            # so everything we need is after the #
            _, comparison = line.split('#', 1)
            comparison = comparison.strip()

            # grapheme breaks strings down by unicode character so we just need
            # to get the first one
            emoji = grapheme.slice(comparison, end=1)
            name = grapheme.slice(comparison, start=2)
            yield emoji, name

    with open(EMOJI_FILE, 'r', encoding='utf-8') as f:
        return {k: v for k, v in generate_pairs(f.readlines())}

DEFAULT_MAPPING = init_emoji_conversion()

def emoji2text(msg, wrap='', other_wrap=None, mapping=None):
    if mapping is None:
        mapping = DEFAULT_MAPPING

    if other_wrap is None:
        l_wrap = wrap
        r_wrap = wrap
    else:
        l_wrap = wrap
        r_wrap = other_wrap

    def generate_message(msg, mapping):
        for c in grapheme.graphemes(msg):
            try:
                yield '{l}{m}{r}'.format(m=mapping[c], l=l_wrap, r=r_wrap)
            except KeyError:
                yield c

    return ''.join(generate_message(msg, mapping))




from setuptools import setup
import unittest

def readme():
    try:
        import pypandoc
        return pypandoc.convert('README.md', 'rst')
    except:
        # Fall back to raw README
        with open('README.md') as f:
            return f.read()

# from https://stackoverflow.com/a/37033551
def my_test_suite():
    test_loader = unittest.TestLoader()
    test_suite = test_loader.discover('emoji2text/tests', pattern='test_*.py')
    return test_suite

setup(
    name='emoji2text',
    version='0.1.7',
    description='Can\'t handle emoji? Use this to treat them as plain strings, according to the description provided by unicode.',
    long_description=readme(),
    keywords='emoji convert text unicode plain',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Topic :: Text Processing :: General'
    ],
    url='https://github.com/SamCB/Emoji2Text',
    author='Sam CB',
    author_email='s.cbird01@gmail.com',
    license='MIT',
    packages=['emoji2text'],
    include_package_data=True,
    install_requires=[
        'grapheme'
    ],
    test_suite='setup.my_test_suite',
    zip_safe=False
)

